@@ -21,6 +21,7 @@
 # ______________________________________________________________________________
 check_attributes <- function(obj) UseMethod('check_attributes', obj)
 
+#' @export
 check_attributes.dsmm_fit_nonparametric <- function(obj) {
     # Check whether `f_is_drifting`, `p_is_drifting` are correctly used.
     if (!is_logical(f_is_drifting <- obj$f_is_drifting)) {
@@ -54,9 +55,9 @@ check_attributes.dsmm_fit_nonparametric <- function(obj) {
                     f_is_drifting = f_is_drifting
                     # , numerical_est = numerical_est
         ),
-        valid_seq(seq = (seq <- obj$seq)),
+        valid_seq(emc = (emc <- obj$emc)),
         valid_model_size(model_size = (model_size <- obj$model_size),
-                         length_seq = (l <- length(seq))),
+                         length_seq = (l <- length(emc))),
         valid_soj_times(soj_times = (soj_times <- obj$soj_times),
                         length_seq = l),
         valid_k_max(k_max = (k_max <- obj$k_max), soj_times = soj_times),
@@ -76,12 +77,12 @@ check_attributes.dsmm_fit_nonparametric <- function(obj) {
         )
     )
     # Check names of the list.
-    names_fit <- c("dist", "seq", "soj_times", "initial_dist", "states",
+    names_fit <- c("dist", "emc", "soj_times", "initial_dist", "states",
                    "s", "degree", "k_max", "model_size", "f_is_drifting",
                    "p_is_drifting", "Model", "estimation", "A_i", "J_i")
     if (!identical((nobj <- names(obj)), names_fit)) {
         msg <- c("\nThe attributes of the object defined are not",
-                 " the same as for a parametric object defined ",
+                 " the same as\nfor a parametric object defined ",
                  "through `nonparametric_dsmm()`.\n")
         extranames <- nobj[which(!nobj %in% names_fit)]
         if (length(extranames) > 0) {
@@ -99,6 +100,7 @@ check_attributes.dsmm_fit_nonparametric <- function(obj) {
     TRUE
 }
 
+#' @export
 check_attributes.dsmm_fit_parametric <- function(obj) {
     # Check whether `f_is_drifting`, `p_is_drifting` are correctly used.
     if (!is_logical(f_is_drifting <- obj$f_is_drifting)) {
@@ -135,9 +137,9 @@ check_attributes.dsmm_fit_parametric <- function(obj) {
                     f_is_drifting = f_is_drifting
                     # , numerical_est = numerical_est
         ),
-        valid_seq(seq = (seq <- obj$seq)),
+        valid_seq(emc = (emc <- obj$emc)),
         valid_model_size(model_size = (model_size <- obj$model_size),
-                         length_seq = (l <- length(seq))),
+                         length_seq = (l <- length(emc))),
         valid_soj_times(soj_times = (soj_times <- obj$soj_times),
                         length_seq = l),
         valid_k_max(k_max = (k_max <- obj$k_max), soj_times = soj_times),
@@ -157,12 +159,12 @@ check_attributes.dsmm_fit_parametric <- function(obj) {
         )
     )
     # Check names of the list.
-    names_fit <- c("dist", "seq", "soj_times", "initial_dist", "states",
+    names_fit <- c("dist", "emc", "soj_times", "initial_dist", "states",
                    "s", "degree", "k_max", "model_size", "f_is_drifting",
                    "p_is_drifting", "Model", "estimation", "A_i", "J_i")
     if (!identical((nobj <- names(obj)), names_fit)) {
         msg <- c("\nThe attributes of the object defined are not",
-                 " the same as for a parametric object defined ",
+                 " the same\nas for a parametric object defined ",
                  "through `nonparametric_dsmm()`.\n")
         extranames <- nobj[which(!nobj %in% names_fit)]
         if (length(extranames) > 0) {
@@ -180,6 +182,7 @@ check_attributes.dsmm_fit_parametric <- function(obj) {
     TRUE
 }
 
+#' @export
 check_attributes.dsmm_nonparametric <- function(obj) {
     # Check whether `f_is_drifting`, `p_is_drifting` are correctly used.
     if (!is_logical(f_is_drifting <- obj$f_is_drifting)) {
@@ -226,7 +229,7 @@ check_attributes.dsmm_nonparametric <- function(obj) {
         "model_size", "f_is_drifting", "p_is_drifting", 'Model', "A_i")
     if (!identical((nobj <- names(obj)), names_nonpar)) {
         msg <- c("\nThe attributes of the object defined are not",
-                 " the same as for a parametric object defined ",
+                 " the same\nas for a parametric object defined ",
                  "through `nonparametric_dsmm()`.\n")
         extranames <- nobj[which(!nobj %in% names_nonpar)]
         if (length(extranames) > 0) {
@@ -244,6 +247,7 @@ check_attributes.dsmm_nonparametric <- function(obj) {
     TRUE
 }
 
+#' @export
 check_attributes.dsmm_parametric <- function(obj) {
     if (!is_logical(f_is_drifting <- obj$f_is_drifting)) {
         stop("\nThe logical parameter `f_is_drifting` should be either ",
@@ -256,7 +260,7 @@ check_attributes.dsmm_parametric <- function(obj) {
     # Check names of dist, in order for `obj$dist[[ i ]]` to work in
     # the next section of `stopifnot`.
     pname <- if (p_is_drifting) 'p_drift' else 'p_notdrift'
-    fname <- if (f_is_drifting) 'f_drift_parametric' else 'f_notdrift'
+    fname <- if (f_is_drifting) 'f_drift_parametric' else 'f_notdrift_parametric'
     fparname <-
         if (f_is_drifting) 'f_drift_parameters' else 'f_notdrift_parameters'
     if (any((names_tmp <- names(obj$dist)) !=
@@ -293,7 +297,7 @@ check_attributes.dsmm_parametric <- function(obj) {
         "f_is_drifting", "p_is_drifting", 'Model', "A_i")
     if (!identical((nobj <- names(obj)), names_par)) {
         msg <- c("\nThe attributes of the object defined are not",
-                 " the same as for a parametric object defined ",
+                 " the same\nas for the parametric object defined ",
                  "through `parametric_dsmm()`.\n")
         extranames <- nobj[which(!nobj %in% names_par)]
         if (length(extranames) > 0) {
@@ -330,7 +334,7 @@ is.dsmm <- function(obj) {
     # Check for missing object, `obj`.
     if (missing(obj)) {
         stop("\nPlease input the `obj` parameter of class `dsmm`. ",
-             "This can be done through the functions\n `fit_dsmm()`, ",
+             "\nThis can be done through the functions:\n `fit_dsmm()`, ",
              "`dsmm_parametric()` and `dsmm_nonparametric()`.")
     }
     # Check for class of object.
@@ -464,8 +468,7 @@ is.dsmm_parametric <- function(obj) {
 #'
 #' @description
 #' This is a generic method that computes and returns the drifting
-#' semi-Markov kernel as a numerical array of dimensions
-#' \eqn{s \times s \times k_{max} \times (n + 1)}.
+#' semi-Markov kernel.
 #'
 #' @param obj An object that inherits from the S3
 #' classes \code{dsmm},
@@ -582,8 +585,8 @@ is.dsmm_parametric <- function(obj) {
 #' @return An array with dimensions of
 #' \eqn{s \times s \times k_{max} \times (n + 1)}, giving the
 #' value of the drifting semi-Markov kernel \eqn{q_{\frac{t}{n}}(u,v,l)} for
-#' the corresponding \eqn{(u,v,l,t)}. If any of \eqn{u,v,l} or \eqn{t} were
-#' specified, their dimension in the array becomes 1.
+#' the corresponding \eqn{(u,v,l,t)}. If any of \eqn{u,v,l} or \eqn{t} are
+#' specified, we obtain the element of the array for their given value.
 #'
 #' @export
 #'
@@ -598,9 +601,9 @@ is.dsmm_parametric <- function(obj) {
 #' @examples
 #' # Setup.
 #' states <- c("Rouen", "Bucharest", "Samos", "Aigio", "Marseille")
-#' seq <- create_sequence(states, probs = c(0.3, 0.1, 0.1, 0.3, 0.2))
+#' emc <- create_sequence(states, probs = c(0.3, 0.1, 0.1, 0.3, 0.2))
 #' obj_model_2 <- fit_dsmm(
-#'     sequence = seq,
+#'     sequence = emc,
 #'     states = states,
 #'     degree = 3,
 #'     f_is_drifting = FALSE,
@@ -650,7 +653,7 @@ get_kernel <- function(obj, t, u, v, l, klim = 100) {
     s <- length(states)
     if (!missing(t)) {
         if (!is_integer(t)) {
-            stop("\nAttribute `t` should be a positive integer, specifying",
+            stop("\nAttribute `t` should be a positive integer,\nspecifying",
                  " the instance of the visited state of your choice.\n",
                  "Currently, it is equal to: ", t)
         }
@@ -663,7 +666,7 @@ get_kernel <- function(obj, t, u, v, l, klim = 100) {
             stopifnot(valid_state(u, states))
         } else if (is_integer(u) && u > s) {
             stop("\nThe previous state `u` is specified as the numbered ",
-                 "state `", u, "` in the state space of total length s = ",
+                 "state `", u, "`,\nin the state space of total length s = ",
                  s, ".")
         }
         u <- states[which(states == u)]
@@ -674,7 +677,7 @@ get_kernel <- function(obj, t, u, v, l, klim = 100) {
         } else if (is_integer(v) && v > s) {
             stop("\nThe previous state `v` is specified as the numbered",
                  " state `", v,
-                 "` in the state space of total length s = ", s, ".")
+                 "`,\n in the state space of total length s = ", s, ".")
         }
         v <- states[which(states == v)]
     }
@@ -829,7 +832,7 @@ print.dsmm <- function(x, ...) {
     check_attributes(x)
     nm <- names(x)
     for (i in seq_along(nm)) {
-        if (!nm[i] %in% c('A_i', 'dist', 'J_i', 'soj_times', 'seq')) {
+        if (!nm[i] %in% c('A_i', 'dist', 'J_i', 'soj_times', 'emc')) {
             cat(paste0("\n$", nm[i], "\n"))
             if (nm[i] %in% c('k_max', 'model_size', 's',
                              'degree', 'states',
@@ -839,7 +842,7 @@ print.dsmm <- function(x, ...) {
             } else {
                 print(x[[i]])
             }
-        } else if (nm[i] %in% c('soj_times', 'seq')) {
+        } else if (nm[i] %in% c('soj_times', 'emc')) {
             cat(paste0("\n$", nm[i], "\n"))
             print(head((xx <- x[[i]]), n = 100L))
             cat(" ... [ output truncated at 100 values -- ommited ",
@@ -919,11 +922,12 @@ print.dsmm_parametric <- function(x, ...) {
 # ______________________________________________________________________________
 # Simulate a sequence from any `dsmm` object.
 # ______________________________________________________________________________
-#' @title Simulate a sequence under a drifting semi-Markov kernel.
-#'
-#' @description Generic function that simulates a number of states \code{nsim}
-#' under the rule of a drifting semi-Markov kernel, which is retrieved from the
-#' object \code{obj}, which in turn inherits from the S3 class \code{dsmm}.
+#' @title Simulate a sequence given a drifting semi-Markov kernel.
+#' @aliases dsmm_simulate
+#' @description Generic function that simulates a sequence under the rule of a
+#' drifting semi-Markov kernel. The number of simulated states is \code{nsim},
+#' while the kernel is retrieved from the object \code{obj} via inheritance
+#' from the S3 class \code{dsmm}.
 #'
 #' @param object An object of S3 class \code{dsmm},
 #' \code{dsmm_fit_nonparametric}, \code{dsmm_nonparametric},
@@ -931,15 +935,15 @@ print.dsmm_parametric <- function(x, ...) {
 #'
 #' @param nsim Optional. An integer specifying the number of simulations to be made
 #' from the drifting semi-Markov kernel. The maximum value of \code{nsim} is the
-#' model size which is specified in \code{obj}, which is also the default value.
+#' model size which is specified in \code{obj}. This is also the default value.
 #' We define a special case for \code{nsim = 0}, where only the initial distribution
 #' is considered and only the simulation of its sojourn time will be made, without
 #' the next state.
 #'
-#' @param seq_length Optional. A positive integer that will ensure the simulated
-#' sequence will not have a \emph{total length} greater than \code{seq_length}
-#' (however, it is possible for the total length to be \emph{less} than
-#' \code{seq_length}).
+#' @param max_seq_length Optional. A positive integer that will ensure the simulated
+#' sequence will not have a \emph{maximum total length} greater than
+#' \code{max_seq_length} (however, it is possible for the total length to be
+#' \emph{less} than \code{max_seq_length}).
 #'
 #' @param seed Optional. An integer specifying the initialization of the random
 #' number generator.
@@ -957,15 +961,24 @@ print.dsmm_parametric <- function(x, ...) {
 #'
 #' For the theoretical background of drifting semi-Markov models: \link{dsmmR}.
 #'
-#' @return A character vector based on \code{nsim} simulations, with a
-#' maximum length of \code{seq_length}.
+#' For obtaining the lengths and values of equals values in a vector:
+#' \code{\link[base:rle]{rle}}.
+#'
+#' @return Returns the simulated sequence for the given drifting
+#'  semi-Markov model. It is a character vector based on \code{nsim} simulations,
+#'  with a maximum length of \code{max_seq_length}.
+#'
+#'  This sequence is not to be confused with the embedded Markov chain. The user
+#'  can apply the \code{base::rle()} function on this simulated sequence, if he wishes
+#'  to obtain the corresponding embedded Markov chain and the sojourn times.
+#'
 #' @export
 #' @examples
 #' # Setup.
-#' seq <- create_sequence("DNA", len = 1000)
-#' states <- sort(unique(seq))
+#' sequence <- create_sequence("DNA", len = 1000)
+#' states <- sort(unique(sequence))
 #' d <- 1
-#' obj_model_3 <- fit_dsmm(sequence = seq,
+#' obj_model_3 <- fit_dsmm(sequence = sequence,
 #'                         states = states,
 #'                         degree = d,
 #'                         f_is_drifting = TRUE,
@@ -974,12 +987,22 @@ print.dsmm_parametric <- function(x, ...) {
 #' # Using the method `simulate.dsmm()`.
 #' simulated_seq <- simulate(obj_model_3, seed = 1)
 #' short_sim <- simulate(obj = obj_model_3, nsim = 10, seed = 1)
-#' cut_sim <- simulate(obj = obj_model_3, seq_length = 10, seed = 1)
+#' cut_sim <- simulate(obj = obj_model_3, max_seq_length = 10, seed = 1)
 #' str(simulated_seq)
 #' str(short_sim)
 #' str(cut_sim)
+#'
+#' # To obtain the embedded Markov chain (EMC) and the corresponding sojourn times
+#' # of any simulated sequence, we can simply use the `base::rle()` function.
+#'
+#' sim_seq_emc <- base::rle(cut_sim)$values # embedded Markov chain
+#' sim_seq_sojourn_times <- base::rle(cut_sim)$lengths # sojourn times
+#' cat("Start of the simulated sequence: ", head(cut_sim),
+#'     "...\nThe embedded Markov chain:       ", head(sim_seq_emc),
+#'     "...\nThe sojourn times:               ", head(sim_seq_sojourn_times), "...")
+#'
 simulate.dsmm <- function(object, nsim = NULL, seed = NULL,
-                          seq_length = NULL, klim = 100, ...) {
+                          max_seq_length = NULL, klim = 100, ...) {
     # Parameters Setup.
     if (missing(object)) {
         stop("\nPlease provide an objectect of class `dsmm`.")
@@ -987,12 +1010,12 @@ simulate.dsmm <- function(object, nsim = NULL, seed = NULL,
                                    'dsmm_parametric'))) {
         stop("\nPlease provide an object of class `dsmm` to use for the",
              " function `simulate()`.",
-             "\nThe object can be created through the functions ",
+             "\nThe object can be created easily through the functions\n",
              "`parametric_dsmm()`, `nonparametric_dsmm()` and `fit_dsmm()`.")
     }
     # Check if nsim and sequence length are given at the same time.
-    if (!is.null(nsim) && !is.null(seq_length)) {
-        stop("\nPlease specify only one of `nsim` or `seq_length` for ",
+    if (!is.null(nsim) && !is.null(max_seq_length)) {
+        stop("\nPlease specify only one of `nsim` or `max_seq_length` for ",
              "the simulation.")
     }
     # Check `nsim`.
@@ -1002,12 +1025,12 @@ simulate.dsmm <- function(object, nsim = NULL, seed = NULL,
         stop("\nThe number of simulations `nsim` ",
              "needs to be a positive integer or 0.")
     }
-    # Check `seq_length`.
-    if (!is.null(seq_length) && !is_integer(seq_length)) {
-        stop("\nThe final length of the sequence `seq_length` ",
+    # Check `max_seq_length`.
+    if (!is.null(max_seq_length) && !is_integer(max_seq_length)) {
+        stop("\nThe final length of the sequence `max_seq_length`,\n",
              "needs to be a positive integer.")
-    } else if (is_integer(seq_length)) {
-        nsim <- seq_length
+    } else if (is_integer(max_seq_length)) {
+        nsim <- max_seq_length
     }
     # Set the RNG seed.
     if (!is.null(seed)) {
@@ -1025,7 +1048,7 @@ simulate.dsmm <- function(object, nsim = NULL, seed = NULL,
     n <- object$model_size
     if (nsim > n) {
         stop("\nThe number of simulations `nsim` = ", nsim,
-             " cannot be larger than the model size, n = ", n)
+             ",\ncannot be larger than the model size, n = ", n)
     }
     kernel <- get_kernel(object, klim = klim)
     k_max <- dim(kernel)[3] # We get `k_max` even for the parametric case.
@@ -1047,14 +1070,13 @@ simulate.dsmm <- function(object, nsim = NULL, seed = NULL,
         u <- vl[1]
     }
     l_vl <- length(vl_vector)
-    seq <- c(initial_state, vl_vector[seq(1, l_vl, 2)])
+    emc <- c(initial_state, vl_vector[seq(1, l_vl, 2)])
     X <- as.numeric(c(vl_vector[seq(2, l_vl, by = 2)], 1))
-    sim_seq <- as.vector(unlist(sapply(seq_along(seq),
-                                       function(i) rep(seq[i], X[i]))))
-    if (is.null(seq_length)) {
+    sim_seq <- as.vector(unlist(sapply(seq_along(emc),
+                                       function(i) rep(emc[i], X[i]))))
+    if (is.null(max_seq_length)) {
         return(sim_seq)
     } else {
-        return(sim_seq[1:seq_length])
+        return(sim_seq[1:max_seq_length])
     }
 }
-
